Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(49)

Unified Diff: src/a64/instrument-a64.cc

Issue 132233055: Consistenly use stderr for printing simulator and debug messages (Closed) Base URL: https://v8.googlecode.com/svn/branches/experimental/a64
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/a64/debugger-a64.h ('k') | src/a64/macro-assembler-a64.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/a64/instrument-a64.cc
diff --git a/src/a64/instrument-a64.cc b/src/a64/instrument-a64.cc
index ee6e07c28d4ae73b95c1dd4e9d44573ffdab069b..93892d9360fb8e11de6958d0045700c37aca436f 100644
--- a/src/a64/instrument-a64.cc
+++ b/src/a64/instrument-a64.cc
@@ -118,15 +118,15 @@ static const CounterDescriptor kCounterList[] = {
Instrument::Instrument(const char* datafile, uint64_t sample_period)
- : output_stream_(stdout), sample_period_(sample_period) {
+ : output_stream_(stderr), sample_period_(sample_period) {
// Set up the output stream. If datafile is non-NULL, use that file. If it
// can't be opened, or datafile is NULL, use stdout.
if (datafile != NULL) {
output_stream_ = fopen(datafile, "w");
if (output_stream_ == NULL) {
- printf("Can't open output file %s. Using stdout.\n", datafile);
- output_stream_ = stdout;
+ fprintf(stderr, "Can't open output file %s. Using stderr.\n", datafile);
+ output_stream_ = stderr;
}
}
@@ -157,7 +157,7 @@ Instrument::~Instrument() {
delete *it;
}
- if (output_stream_ != stdout) {
+ if (output_stream_ != stderr) {
fclose(output_stream_);
}
}
@@ -118,15 +118,15 @@ static const CounterDescriptor kCounterList[] = {
// Set up the output stream. If datafile is non-NULL, use that file. If it
- // can't be opened, or datafile is NULL, use stdout.
+ // can't be opened, or datafile is NULL, use stderr.
if (datafile != NULL) {
output_stream_ = fopen(datafile, "w");
« no previous file with comments | « src/a64/debugger-a64.h ('k') | src/a64/macro-assembler-a64.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698